<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'top_travel_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','top-travel-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',
	'active_callback' 	=> 'top_travel_pro_is_slider_design_enable',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[slider_section_enable]', array(
		'selector'            => '#featured-slider-section div.wrapper',
		'settings'            => 'top_travel_pro_theme_options[slider_section_enable]',
    ) );
}

// Slider content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
	'active_callback' 	=> 'top_travel_pro_is_slider_section_enable',
) ) );

// Slider content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[slider_arrow]', array(
	'default'			=> 	$options['slider_arrow'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[slider_arrow]', array(
	'label'             => esc_html__( 'Slider Arrow', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
	'active_callback' 	=> 'top_travel_pro_is_slider_section_enable',
) ) );

// Slider btn label setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[slider_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[slider_btn_label]', array(
	'label'           	=> esc_html__( 'Slider Button Label', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_slider_section',
	'active_callback' 	=> 'top_travel_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[slider_btn_label]', array(
		'selector'            => '#featured-slider-section .read-more a.btn.btn-fill',
		'settings'            => 'top_travel_pro_theme_options[slider_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_slider_btn_label_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'top_travel_pro_sanitize_number_range',
	'validate_callback' => 'top_travel_pro_validate_slider_count',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'top-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'active_callback'   => 'top_travel_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_slider_section_enable',
	'choices'			=> top_travel_pro_main_slider_content_type(),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

	if ( $options['home_layout'] == 'fourth-design' ):
	// Slider btn label setting and control
	$wp_customize->add_setting( 'top_travel_pro_theme_options[slider_subtitle_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

	$wp_customize->add_control( 'top_travel_pro_theme_options[slider_subtitle_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Subtitle %d', 'top-travel-pro' ), $i ),
		'section'        	=> 'top_travel_pro_slider_section',
		'active_callback' 	=> 'top_travel_pro_is_slider_section_enable',
		'type'				=> 'text',
	) );
	endif;

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_slider_section',
		'choices'			=> top_travel_pro_page_choices(),
		'active_callback'	=> 'top_travel_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_slider_section',
		'choices'			=> top_travel_pro_post_choices(),
		'active_callback'	=> 'top_travel_pro_is_slider_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'top_travel_pro_theme_options[slider_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[slider_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_slider_section',
		'choices'			=> top_travel_pro_trip_choices(),
		'active_callback'	=> 'top_travel_pro_is_slider_section_content_trip_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'top-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_slider_section_content_category_enable'
) ) );


// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[slider_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[slider_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_slider_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[slider_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[slider_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_slider_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[slider_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[slider_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_slider_section_content_destination_enable'
) ) );


/*slider color options*/

// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[title_color]', array(
	'label'             => esc_html__( 'Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'active_callback' 	=> 'top_travel_pro_is_slider_section_enable',
	) ) );

// Header title hover color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[title_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[title_hover_color]', array(
	'label'             => esc_html__( 'Title Hover Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'active_callback' 	=> 'top_travel_pro_is_slider_section_enable',
	) ) );

if( in_array( $options['home_layout'], array( 'second-design', 'third-design', 'sixth-design', 'seventh-design', 'eighth-design', 'ninth-design', 'tenth-design' ) ) ):
// excerpt color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[excerpt_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[excerpt_color]', array(
	'label'             => esc_html__( 'Excerpt Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'active_callback' 	=> 'top_travel_pro_is_slider_section_enable',
	) ) );

endif;

if( $options['home_layout'] !=='fourth-design' ){
// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[button_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[button_color]', array(
	'label'             => esc_html__( 'Button Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'active_callback' 	=> 'top_travel_pro_is_slider_section_enable',
	) ) );


// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[button_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[button_hover_color]', array(
	'label'             => esc_html__( 'Button Hover Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'active_callback' 	=> 'top_travel_pro_is_slider_section_enable',
	) ) );
}

// Button title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[btn_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[btn_title_color]', array(
	'label'             => esc_html__( 'Button Text Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_slider_section',
	'active_callback' 	=> 'top_travel_pro_is_slider_section_enable',
	) ) );