<?php
/**
 * Top Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add Topbar section
$wp_customize->add_section( 'top_travel_pro_top_section', array(
	'title'             => esc_html__( 'Topbar','top-travel-pro' ),
	'description'       => esc_html__( 'Topbar Section options.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',
	'active_callback' 	=> 'top_travel_pro_is_topbar_design_enable',
	) );

// Topbar content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[top_section_enable]', array(
	'default'			=> 	$options['top_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[top_section_enable]', array(
	'label'             => esc_html__( 'Topbar Section Enable', 'top-travel-pro' ),
	'description'       => sprintf( '%1$s <a class="topbar-menu-trigger" href="#"> %2$s </a> %3$s', esc_html__( 'Note: To show topbar menu.', 'top-travel-pro' ), esc_html__( 'Click Here', 'top-travel-pro' ), esc_html__( 'to create menu', 'top-travel-pro' ) ),
	'section'           => 'top_travel_pro_top_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
	) ) );

// top description setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[top_contact_info]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['top_contact_info'],
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[top_contact_info]', array(
	'label'           	=> esc_html__( 'Contact Info', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_top_section',
	'active_callback' 	=> 'top_travel_pro_is_topbar_section_enable',
	'type'				=> 'textarea',
) );

if( $options['home_layout'] == 'fifth-design' ):
// Top ads image setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[top_bar_ads_image]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_image',
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'top_travel_pro_theme_options[top_bar_ads_image]',
		array(
		'label'       		=> esc_html__( 'Select Ads Image', 'top-travel-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'top-travel-pro' ), 728, 90 ),
		'section'     		=> 'top_travel_pro_top_section',
) ) );

// Top ads image setting and contro url.
$wp_customize->add_setting( 'top_travel_pro_theme_options[top_bar_ads_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[top_bar_ads_url]', array(
	'label'           	=> esc_html__( 'Ads image URL', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_top_section',
	'type'				=> 'text'
) );

endif;

/*color options*/

// Section sub title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[topbar_bg_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[topbar_bg_color]', array(
	'label'             => esc_html__( 'Topbar background Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_top_section',
	'active_callback' 	=> 'top_travel_pro_is_topbar_section_enable',
	) ) );

// Section title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[topbar_text_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[topbar_text_color]', array(
	'label'             => esc_html__( 'Topbar Text Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_top_section',
	'active_callback' 	=> 'top_travel_pro_is_topbar_section_enable',
	) ) );

// Service title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[topbar_text_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[topbar_text_hover_color]', array(
	'label'             => esc_html__( 'Topbar Text Hover Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_top_section',
	'active_callback' 	=> 'top_travel_pro_is_topbar_section_enable',
	) ) );