<?php
/**
 * Trending Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add Trending section
$wp_customize->add_section( 'top_travel_pro_trending_section', array(
	'title'             => esc_html__( 'Trending Posts','top-travel-pro' ),
	'description'       => esc_html__( 'Trending Section options.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',
	'active_callback' 	=> 'top_travel_pro_is_trending_design_enable',
) );

// Trending content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[trending_section_enable]', array(
	'default'			=> 	$options['trending_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[trending_section_enable]', array(
	'label'             => esc_html__( 'Trending Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_trending_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[trending_section_enable]', array(
		'selector'            => '#testimonial-section .wrapper',
		'settings'            => 'top_travel_pro_theme_options[trending_section_enable]',
    ) );
}

// Trending btn label setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[trending_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['trending_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[trending_title]', array(
	'label'           	=> esc_html__( 'Trending Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_trending_section',
	'active_callback' 	=> 'top_travel_pro_is_trending_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[trending_title]', array(
		'selector'            => '#testimonial-section h2.section-title',
		'settings'            => 'top_travel_pro_theme_options[trending_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_trending_title_partial',
    ) );
}

if ( in_array( $options['home_layout'], array( 'default-design', 'third-design', 'eighth-design', 'ninth-design', 'tenth-design' ) ) ): 

// Trending btn label setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[trending_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['trending_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[trending_subtitle]', array(
	'label'           	=> esc_html__( 'Subtitle', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_trending_section',
	'active_callback' 	=> 'top_travel_pro_is_trending_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[trending_subtitle]', array(
		'selector'            => '#testimonial-section p.section-subtitle',
		'settings'            => 'top_travel_pro_theme_options[trending_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_trending_subtitle_partial',
    ) );
}

endif;

// Event social icons number control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[trending_count]', array(
	'default'          	=> $options['trending_count'],
	'sanitize_callback' => 'top_travel_pro_sanitize_number_range',
	'validate_callback' => 'top_travel_pro_validate_trending_count',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[trending_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'top-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_trending_section',
	'active_callback'   => 'top_travel_pro_is_trending_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Trending content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[trending_content_type]', array(
	'default'          	=> $options['trending_content_type'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[trending_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_trending_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_trending_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'top-travel-pro' ),
		'post'      => esc_html__( 'Post', 'top-travel-pro' ),
		'category'  => esc_html__( 'Category', 'top-travel-pro' ),
		),
) );

for ( $i = 1; $i <= $options['trending_count']; $i++ ) :
	// trending pages drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[trending_content_page_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[trending_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_trending_section',
		'choices'			=> top_travel_pro_page_choices(),
		'active_callback'	=> 'top_travel_pro_is_trending_section_content_page_enable',
	) ) );

	// trending posts drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[trending_content_post_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[trending_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_trending_section',
		'choices'			=> top_travel_pro_post_choices(),
		'active_callback'	=> 'top_travel_pro_is_trending_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[trending_content_category]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[trending_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'top-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_trending_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_trending_section_content_category_enable'
) ) );


/*color options*/

if( $options['home_layout'] !== 'fifth-design' ){

// Section sub title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_section_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_section_subtitle_color]', array(
	'label'             => esc_html__( 'Section Sub Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_trending_section',
	'active_callback' 	=> 'top_travel_pro_is_trending_section_enable',
	) ) );

// Section title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_trending_section',
	'active_callback' 	=> 'top_travel_pro_is_trending_section_enable',
	) ) );

// Trending title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_title_color]', array(
	'label'             => esc_html__( 'Trending Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_trending_section',
	'active_callback' 	=> 'top_travel_pro_is_trending_section_enable',
	) ) );

// Trending title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_hover_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_hover_title_color]', array(
	'label'             => esc_html__( 'Trending Hover Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_trending_section',
	'active_callback' 	=> 'top_travel_pro_is_trending_section_enable',
	) ) );

// Trending description color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[testimonial_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[testimonial_description_color]', array(
	'label'             => esc_html__( 'Trending Description Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_trending_section',
	'active_callback' 	=> 'top_travel_pro_is_trending_section_enable',
	) ) );

}

