<?php
/**
 * Latest Products section
 *
 * This is the template for the content of latest_products section
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */
if ( ! function_exists( 'top_travel_pro_add_latest_products_section' ) ) :
    /**
    * Add latest_products section
    *
    *@since Top Travel Pro 1.0.0
    */
    function top_travel_pro_add_latest_products_section() {
    	$options = top_travel_pro_get_theme_options();
        // Check if latest_products is enabled on frontpage
        $latest_products_enable = apply_filters( 'top_travel_pro_section_status', true, 'latest_products_section_enable' );

         if ( !in_array( $options['home_layout'], array( 'default-design', 'sixth-design' ) ) ) {
             $latest_products_enable = false;
        }

        if ( ( true !== $latest_products_enable) || ! class_exists( 'WooCommerce' ) ) {
            return false;
        }
        // Get latest_products section details
        $section_details = array();
        $section_details = apply_filters( 'top_travel_pro_filter_latest_products_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render latest_products section now.
        top_travel_pro_render_latest_products_section( $section_details );
    }
endif;

if ( ! function_exists( 'top_travel_pro_get_latest_products_section_details' ) ) :
    /**
    * latest_products section details.
    *
    * @since Top Travel Pro 1.0.0
    * @param array $input latest_products section details.
    */
    function top_travel_pro_get_latest_products_section_details( $input ) {
        $options = top_travel_pro_get_theme_options();

        // Content type.
        $latest_products_content_type  = $options['latest_products_content_type'];
        $latest_products_count = ! empty( $options['latest_products_count'] ) ? $options['latest_products_count'] : 2;
        
        $content = array();
        switch ( $latest_products_content_type ) {

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $latest_products_count; $i++ ) {
                    if ( ! empty( $options['latest_products_content_product_' . $i] ) ) {
                        $page_ids[] = $options['latest_products_content_product_' . $i];
                    }
                }
                
                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $latest_products_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'product-category':
                $cat_id = ! empty( $options['latest_products_content_product_category'] ) ? $options['latest_products_content_product_category'] : '';
                $args = array(
                    'post_type'      => 'product',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'product_cat',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $latest_products_count ),
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
               
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// latest_products section content details.
add_filter( 'top_travel_pro_filter_latest_products_section_details', 'top_travel_pro_get_latest_products_section_details' );


if ( ! function_exists( 'top_travel_pro_render_latest_products_section' ) ) :
  /**
   * Start latest_products section
   *
   * @return string latest_products content
   * @since Top Travel Pro 1.0.0
   *
   */
   function top_travel_pro_render_latest_products_section( $content_details = array() ) {
        $options = top_travel_pro_get_theme_options();
        $latest_products_content_type  = $options['latest_products_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="latest-products" class="relative page-section same-background">
            <div class="wrapper">
                <div class="col-2 clear">

                    <?php foreach ( $content_details as $content ) : ?>

                        <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                    </header>
                                </div><!-- .entry-container -->
                            </div><!-- .featured-image -->
                        </article>

                    <?php endforeach; ?>
                    
                </div><!-- .grid --> 
            </div><!-- .wrapper -->
        </div><!-- #latest-products -->
    
    <?php }
endif;