<?php
/**
* Most Viewed section
*
* This is the template for the content of most_viewed section
*
* @package Theme Palace
* @subpackage Top Travel Pro
* @since Top Travel Pro 1.0.0
*/

$options = top_travel_pro_get_theme_options();

if( in_array( $options['home_layout'], array( 'fifth-design' ) ) ){

if( $options['most_viewed_section_enable'] !== false ):

// Content type.
$most_viewed_content_type  = $options['most_viewed_content_type'];
$most_viewed_count = ! empty( $options['most_viewed_count'] ) ? $options['most_viewed_count'] : 2;
$content_details = array();
switch ( $most_viewed_content_type ) {

    case 'page':
    $page_ids = array();
    $author = array();

    for ( $i = 1; $i <= $most_viewed_count; $i++ ) {
        if ( ! empty( $options['most_viewed_content_page_' . $i] ) ) :
            $page_ids[] = $options['most_viewed_content_page_' . $i];
        endif;
    }

    $args = array(
        'post_type'         => 'page',
        'post__in'          => ( array ) $page_ids,
        'posts_per_page'    => absint( $most_viewed_count ),
        'orderby'           => 'post__in',
        );                    
    break;

    case 'post':
    $post_ids = array();
    $author = array();

    for ( $i = 1; $i <= $most_viewed_count; $i++ ) {
        if ( ! empty( $options['most_viewed_content_post_' . $i] ) ) :
            $post_ids[] = $options['most_viewed_content_post_' . $i];
        endif;
    }

    $args = array(
        'post_type'         => 'post',
        'post__in'          => ( array ) $post_ids,
        'posts_per_page'    => absint( $most_viewed_count ),
        'orderby'           => 'post__in',
        'ignore_sticky_posts'   => true,
        );                    
    break;

    case 'category':
    $cat_id = ! empty( $options['most_viewed_content_category'] ) ? $options['most_viewed_content_category'] : '';
    $args = array(
        'post_type'         => 'post',
        'posts_per_page'    => absint( $most_viewed_count ),
        'cat'               => absint( $cat_id ),
        'ignore_sticky_posts'   => true,
        );                    
    break;

    default:
    break;
}

// Run The Loop.
$query = new WP_Query( $args );
if ( $query->have_posts() ) : 
    while ( $query->have_posts() ) : $query->the_post();
$page_post['id']        = get_the_id();
$page_post['title']     = get_the_title();
$page_post['url']       = get_the_permalink();
$page_post['excerpt']   = top_travel_pro_trim_content( 18 );
$page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
array_push( $content_details, $page_post );
endwhile;
endif;
wp_reset_postdata();

?>

<div id="magazine-most-viewed-posts">
    <?php if( !empty( $options['most_viewed_title'] ) ): ?>
        <div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $options['most_viewed_title'] ); ?></h2>
        </div><!-- .section-header -->
    <?php endif; ?>

    <div class="section-content col-2 clear">

        <?php foreach ( $content_details as $content ) : ?>

            <article class="has-post-thumbnail">
                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                </div><!-- .featured-image -->

                <div class="entry-container">
                    <ul class="post-categories">
                     <?php the_category( '', '', $content['id'] ); ?>
                 </ul>

                 <header class="entry-header">
                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                </header>   

                <div class="entry-content">
                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                </div><!-- .entry-content -->
            </div><!-- .entry-container -->
        </article>

    <?php endforeach; ?>

</div><!-- .section-content -->
</div><!-- #magazine-most-viewed-posts -->

<?php
endif;

}