<?php
/**
 * Package section
 *
 * This is the template for the content of package section
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */
if ( ! function_exists( 'top_travel_pro_add_package_section' ) ) :
    /**
    * Add package section
    *
    *@since Top Travel Pro 1.0.0
    */
    function top_travel_pro_add_package_section() {
    	$options = top_travel_pro_get_theme_options();
        // Check if destination is enabled on frontpage
        $package_enable = apply_filters( 'top_travel_pro_section_status', true, 'package_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design' ) ) ) {
             $package_enable = false;
        }

        if ( true !== $package_enable ) {
            return false;
        }
        // Get destination section details
        $section_details = array();
        $section_details = apply_filters( 'top_travel_pro_filter_package_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render destination section now.
        top_travel_pro_render_package_section( $section_details );
    }
endif;

if ( ! function_exists( 'top_travel_pro_get_package_section_details' ) ) :
    /**
    * package section details.
    *
    * @since Top Travel Pro 1.0.0
    * @param array $input package section details.
    */
    function top_travel_pro_get_package_section_details( $input ) {
        $options = top_travel_pro_get_theme_options();

        // Content type.
        $package_content_type  = $options['package_content_type'];
        
        $content = array();
        $args = array();
        $content['cats'] = array();
        switch ( $package_content_type ) {
        	
            case 'category':
                $cat_ids = ! empty( $options['package_content_category'] ) ? $options['package_content_category'] : array();

                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'         => 'post',
                        'posts_per_page'    => 4,
                        'cat'               => absint( $cat_id ),
                        'ignore_sticky_posts'   => true,
                        );
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;               
            break;

            case 'trip-types':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_ids = ! empty( $options['package_content_trip_types'] ) ? $options['package_content_trip_types'] : array();

                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'      => 'itineraries',
                        'tax_query' => array(
                            array(
                                'taxonomy' => 'itinerary_types',
                                'field'    => 'id',
                                'terms'    => $cat_id,
                            ),
                        ),
                        'posts_per_page'  => 4,
                        );
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;                
                $content['taxonomy'] = 'itinerary_types';
            break;

            case 'destination':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_ids = ! empty( $options['package_content_destination'] ) ? $options['package_content_destination'] : array();

                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'      => 'itineraries',
                        'tax_query' => array(
                            array(
                                'taxonomy' => 'travel_locations',
                                'field'    => 'id',
                                'terms'    => $cat_id,
                            ),
                        ),
                        'posts_per_page'  => 4,
                        ); 
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;                   
                $content['taxonomy'] = 'travel_locations';
            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_ids = ! empty( $options['package_content_activity'] ) ? $options['package_content_activity'] : array();

                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'      => 'itineraries',
                        'tax_query' => array(
                            array(
                                'taxonomy' => 'activity',
                                'field'    => 'id',
                                'terms'    => $cat_id,
                            ),
                        ),
                        'posts_per_page'  => 4,
                        ); 
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;                   
                $content['taxonomy'] = 'activity';
            break;

            default:
            break;
        }

        $i = 0;
        foreach ( $args as $arg ) :
            $content['details'][$i] = array();
            // Run The Loop.
            $query = new WP_Query( $arg );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post[$i]['id']        = get_the_id();
                    $page_post[$i]['title']     = get_the_title();
                    $page_post[$i]['url']       = get_the_permalink();
                    $page_post[$i]['excerpt']       = top_travel_pro_trim_content( 35 );
                    $page_post[$i]['image']  	 = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content['details'][$i], $page_post[$i] );
                endwhile;
            endif;
            wp_reset_postdata();
            $i++;
        endforeach;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// destination section content details.
add_filter( 'top_travel_pro_filter_package_section_details', 'top_travel_pro_get_package_section_details' );


if ( ! function_exists( 'top_travel_pro_render_package_section' ) ) :
  /**
   * Start destination section
   *
   * @return string destination content
   * @since Top Travel Pro 1.0.0
   *
   */
   function top_travel_pro_render_package_section( $content_details = array() ) {
        $options = top_travel_pro_get_theme_options();
        $package_content_type  = $options['package_content_type'];
        $package_bg_image = $options['package_bg_image'] !== '' ? $options['package_bg_image'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="recommended-hotels" class="relative page-section recommended-hotels-package" style="background-image: url('<?php echo esc_url( $package_bg_image ) ; ?>');">
                <div class="wrapper recommended-hotels-wrapper">
                    <div class="section-header-wrapper">
                        
                        <div class="section-header recommended-hotels-header">
                            <?php if ( ! empty( $options['package_sub_title'] ) ) : ?>
                                <p class="section-subtitle recommended-hotels-subtitle"><?php echo esc_html( $options['package_sub_title'] ); ?></p>
                            <?php endif; ?>
                            <?php if ( ! empty( $options['package_title'] ) ) : ?>
                                <h2 class="section-title recommended-hotels-title"><?php echo esc_html( $options['package_title'] ); ?></h2>
                            <?php endif; ?>
                        </div><!-- .section-header -->
                        

                        <div class="slick-filtering">
                            <ul class="slick-nav">
                                <?php $i = 1; foreach ( $content_details['cats'] as $content ) :
                                if ( 'category' == $package_content_type ) : ?>
                                    <li class="<?php echo ( $i == 1 ) ? 'active' : ''; ?>"><a href="#" data-slug="<?php echo 'package-' . absint( $content ); ?>"><?php echo esc_html( get_cat_name( $content ) ); ?></a></li>
                                <?php else : 
                                    $cat = get_term_by( 'id', $content, $content_details['taxonomy'] );  ?>
                                    <li class="<?php echo ( $i == 1 ) ? 'active' : ''; ?>"><a href="#" data-slug="<?php echo 'package-' . absint( $content ); ?>"><?php echo esc_html( $cat->name ); ?></a></li>
                                <?php endif;
                            $i++; endforeach; ?>
                            </ul>
                        </div><!-- .slick-filtering -->
                    </div><!-- .section-header-wrapper -->

                    <div class="hotels-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": false, "speed": 1000, "dots": false, "arrows":false, "autoplay": false, "draggable": true, "fade": false }'>
                        <?php $i = 0; foreach ( $content_details['details'] as $content_detail ) : ?>
                            <?php foreach ( $content_detail as $content ) : ?>
                                <?php if ( 'category' !== $package_content_type ) :
                                    $price_key = '';
                                    $sale_enabled = get_post_meta( $content['id'], 'wp_travel_enable_sale', true );
                                    if( wp_travel_is_enable_pricing_options( $content['id'] ) ) {
                                        
                                        $pricing_options = get_post_meta( $content['id'], 'wp_travel_pricing_options', true );
                                        $price_key = wp_travel_get_min_price_key( $pricing_options );
                                    }

                                    $trip_price = WP_Travel_Helpers_Pricings::get_price(array('trip_id'=>$content['id'], 'price_key'=>$price_key));
                                endif; ?>

                                <article class="<?php echo 'package-' . absint( $content_details['cats'][$i] ); ?>">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                        <?php if ( 'category' !== $package_content_type ) : 
                                            if ( false !== $sale_enabled && '1' === $sale_enabled ) : ?>
                                                <div class="wp-travel-offer">
                                                    <span><?php esc_html_e( 'Offer', 'top-travel-pro' ); ?></span>
                                                </div>
                                            <?php endif; 
                                        endif; ?>
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link">
                                        </a><!-- .more-link -->
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ) ; ?></p>
                                        </div><!-- .entry-content -->
                                        <?php if ( 'category' !== $package_content_type ) : ?>
                                            <span class="trip-price">                    
                                                <?php echo wp_travel_get_formated_price_currency( $trip_price ); ?>
                                            </span><!-- .trip-price -->

                                       <?php endif ; ?>

                                       <?php if ( !empty( $options['package_btn_title'] ) ): ?>
                                           <div class="read-more">
                                                <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="btn"><?php echo esc_html( $options['package_btn_title'] ) ?></a>
                                            </div><!-- .read-more -->
                                       <?php endif ?>
                                        
                                    </div><!-- .entry-container -->
                                </article>
                            <?php endforeach; ?>
                        <?php $i++; endforeach; ?>
                       
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #recommended-hotels -->
     
        
    <?php }
endif;