<?php
/**
 * Recent section
 *
 * This is the template for the content of recent section
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */
if ( ! function_exists( 'top_travel_pro_add_recent_section' ) ) :
    /**
    * Add recent section
    *
    *@since Top Travel Pro 1.0.0
    */
    function top_travel_pro_add_recent_section() {
        $options = top_travel_pro_get_theme_options();
        // Check if recent is enabled on frontpage
        $recent_enable = apply_filters( 'top_travel_pro_section_status', true, 'recent_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'third-design', 'fourth-design', 'tenth-design' ) ) ) {
             $recent_enable = false;
        }

        if ( true !== $recent_enable ) {
            return false;
        }
        // Get recent section details
        $section_details = array();
        $section_details = apply_filters( 'top_travel_pro_filter_recent_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render recent section now.
        top_travel_pro_render_recent_section( $section_details );
    }
endif;

if ( ! function_exists( 'top_travel_pro_get_recent_section_details' ) ) :
    /**
    * recent section details.
    *
    * @since Top Travel Pro 1.0.0
    * @param array $input recent section details.
    */
    function top_travel_pro_get_recent_section_details( $input ) {
        $options = top_travel_pro_get_theme_options();

        // Content type.
        $recent_content_type  = $options['recent_content_type'];
        $recent_count = ! empty( $options['recent_count'] ) ? $options['recent_count'] : 3;
        $content = array();
        switch ( $recent_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $recent_count; $i++ ) {
                    if ( ! empty( $options['recent_content_page_' . $i] ) ) :
                        $page_ids[] = $options['recent_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $recent_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $recent_count; $i++ ) {
                    if ( ! empty( $options['recent_content_post_' . $i] ) ) :
                        $post_ids[] = $options['recent_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $recent_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['recent_content_category'] ) ? $options['recent_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $recent_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        $i = 0;
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = top_travel_pro_trim_content( 30 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// recent section content details.
add_filter( 'top_travel_pro_filter_recent_section_details', 'top_travel_pro_get_recent_section_details' );


if ( ! function_exists( 'top_travel_pro_render_recent_section' ) ) :
  /**
   * Start recent section
   *
   * @return string recent content
   * @since Top Travel Pro 1.0.0
   *
   */
   function top_travel_pro_render_recent_section( $content_details = array() ) {
        $options = top_travel_pro_get_theme_options();
        $recent_bg_image = !empty( $options['recent_bg_image'] ) ? $options['recent_bg_image'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="recommended-hotels" class="relative page-section recent-section" style="background-image: url('<?php echo esc_url( $recent_bg_image ) ; ?>');">
                <div class="wrapper recent-wrapper">
                    <div class="section-header-wrapper">
                        <div class="section-header">
                        <?php if( !empty( $options['recent_subtitle'] ) ): ?>
                            <p class="section-subtitle recent-subtitle"><?php echo esc_html( $options['recent_subtitle'] ); ?></p>
                        <?php endif; 
                        if( !empty( $options['recent_title'] ) ):
                        ?>
                            <h2 class="section-title recent-title"><?php echo esc_html( $options['recent_title'] ); ?></h2>
                        <?php endif; ?>
                        </div><!-- .section-header -->

                    </div><!-- .section-header-wrapper -->

                    <div class="hotels-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": false, "speed": 1000, "dots": false, "arrows":false, "autoplay": false, "draggable": true, "fade": false }'>
                       
                       <?php foreach ( $content_details as $content ) : ?>

                        <article class="all paris">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                            <?php if ( $options['home_layout'] == 'third-design' ): ?>
                                <span class="cat-links">
                                    <ul class="post-categories">
                                        <?php the_category( '', '', $content['id'] ) ?>
                                    </ul><!-- .post-categories -->
                                </span><!-- .cat-links -->
                            <?php endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <?php if ( $options['home_layout'] == 'fourth-design' ): ?>
                                    <span class="cat-links">
                                        <ul class="post-categories">
                                            <?php the_category( '', '', $content['id'] ) ?>
                                        </ul><!-- .post-categories -->
                                    </span><!-- .cat-links -->
                                <?php endif;

                                if ( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'tenth-design' ): ?>
                                <div class="entry-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                                <?php endif;

                                if ( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fourth-design' ){

                                if( !empty( $options['recent_button'] ) ): ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['recent_button'] ); ?></a>
                                </div><!-- .read-more -->
                            <?php endif;
                                }
                            ?>
                            </div><!-- .entry-container -->
                        </article>

                        <?php endforeach ; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>

    <?php }
endif;
