<?php
/**
 * team section
 *
 * This is the template for the content of team section
 *
 * @team Theme Palace
 * @subteam Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */
if ( ! function_exists( 'top_travel_pro_add_team_section' ) ) :
    /**
    * Add team section
    *
    *@since Top Travel Pro 1.0.0
    */
    function top_travel_pro_add_team_section() {
        $options = top_travel_pro_get_theme_options();
        // Check if team is enabled on frontpage
        $team_enable = apply_filters( 'top_travel_pro_section_status', true, 'team_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'second-design', 'seventh-design', 'eighth-design', 'ninth-design' ) ) ) {
             $team_enable = false;
        }

        if ( true !== $team_enable ) {
            return false;
        }
        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'top_travel_pro_filter_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render team section now.
        top_travel_pro_render_team_section( $section_details );
    }
endif;

if ( ! function_exists( 'top_travel_pro_get_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since Top Travel Pro 1.0.0
    * @param array $input team section details.
    */
    function top_travel_pro_get_team_section_details( $input ) {
        $options = top_travel_pro_get_theme_options();

        // Content type.
        $team_content_type  = $options['team_content_type'];
        $team_count  = ! empty( $options['team_count'] ) ? $options['team_count'] : 3;
        
        $content = array();
        switch ( $team_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_page_' . $i] ) )
                        $page_ids[] = $options['team_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $team_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_post_' . $i] ) )
                        $post_ids[] = $options['team_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => $team_count,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['team_content_category'] ) ? $options['team_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => $team_count,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = top_travel_pro_trim_content( 15 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'top_travel_pro_filter_team_section_details', 'top_travel_pro_get_team_section_details' );


if ( ! function_exists( 'top_travel_pro_render_team_section' ) ) :
  /**
   * Start team section
   *
   * @return string team content
   * @since Top Travel Pro 1.0.0
   *
   */
   function top_travel_pro_render_team_section( $content_details = array() ) {
        $options = top_travel_pro_get_theme_options();
        $i = 1;        

        if ( empty( $content_details ) ) {
            return;
        } 
        ?> 
            <div id="recommended-hotels" class="relative page-section team-section">
                <div class="wrapper team-wrapper">
                    <div class="section-header-wrapper">
                        
                        <div class="section-header">
                            <?php if ( ! empty( $options['team_sub_title'] ) ) : ?>
                                <p class="section-subtitle team-subtitle"><?php echo esc_html( $options['team_sub_title'] ); ?></p>
                            <?php endif; ?>
                            <?php if ( ! empty( $options['team_title'] ) ) : ?>
                                <h2 class="section-title team-title"><?php echo esc_html( $options['team_title'] ); ?></h2>
                            <?php endif; ?>
                        </div><!-- .section-header -->
                    </div> 
                    <div class="hotels-slider" data-slick='{"slidesToShow": <?php echo esc_attr( $options['team_column'] ); ?>, "slidesToScroll": 1, "infinite": false, "speed": 1000, "dots": false, "arrows": false, "autoplay": false, "draggable": true, "fade": false }'>
        
                        <?php $i = 1; foreach ( $content_details as $content ) : ?>
                            <article >
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link">
                                    </a><!-- .more-link -->
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                    </header>

                                    <?php if ( !empty( $options['team_position_'.$i] )): ?>
                                        <div class="entry-content">
                                            <p><?php echo esc_html( $options['team_position_'.$i] ) ; ?></p>
                                        </div><!-- .entry-content -->
                                    <?php endif ?>
                                    
                                    
                                    <div class="social-icons">
                                        <ul>
                                            <?php 
                                            $team_socials = ! empty( $options['team_social_' . $i ] ) ? explode( '|', $options['team_social_' . $i ] ) : array(); 

                                            foreach ( $team_socials as $team_social ) : ?>
                                                <li>
                                                    <a href="<?php echo esc_url( $team_social ); ?>"><?php echo top_travel_pro_return_social_icon( $team_social ); ?></a>
                                                </li>
                                            <?php endforeach; ?>
                                        </ul>
                                    </div><!-- .social-icons -->

                                </div><!-- .entry-container -->
                            </article>
                        <?php $i++; endforeach; ?>
                       
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #recommended-hotels -->
    <?php }
endif;